@@ -1,31 +1,46 @@
-#' Radial bar plot of use reports (UR) per species
+#' Radial bar plot of ethnobotany indices
 #'
-#' Creates a radial bar plot of use reports (UR) per species based on the `UR function`.
+#' Creates a radial bar plot of ethnobotany indices in ethnobotanyR package using the ggplot2 library <https://ggplot2.tidyverse.org/>.
 #' @param data is an ethnobotany data set with column 1 'informant' and 2 'sp_name' as row identifiers of informants and of species names respectively.
 #' The rest of the columns are the identified ethnobotany use categories. The data should be populated with counts of uses per person (should be 0 or 1 values).
 #' @param analysis is one of the quantitative ethnobotany functions from ethnobotanyR, i.e. ethnobotanyR::FCs.
-#' @keywords ethnobotany visualuzation radial bar plot
+#' 
+#' @keywords graphs arith math logic methods misc survey
 #'
-#' @importFrom magrittr %>%
-#' @importFrom dplyr filter summarize select left_join group_by 
-#' @importFrom assertthat validate_that see_if
-#' @importFrom ggplot2 ggplot aes geom_bar coord_polar theme_minimal geom_bar scale_y_continuous
+#' @return Radial bar plot of chosen ethnobotany indices in ethnobotanyR package.
+#' 
+#' @section Warning:
+#' 
+#' Identification for informants and species must be listed by the names 'informant' and 'sp_name' respectively in the data set.
+#' The rest of the columns should all represent separate identified ethnobotany use categories. These data should be populated with counts of uses per informant (should be 0 or 1 values).
+#' 
 #' @importFrom cowplot plot_grid
+#' @importFrom dplyr filter summarize select left_join group_by 
+#' @importFrom ggplot2 ggplot aes geom_bar coord_polar theme_minimal geom_bar scale_y_continuous
+#' @importFrom magrittr %>%
 #'  
 #' @examples
 #' 
 #' #Use built-in ethnobotany data example and Frequency of Citation function FCs()
+#' 
 #' Radial_plot(ethnobotanydata, analysis = FCs)
 #' 
 #' #Generate random dataset of three informants uses for four species
+#' 
 #' eb_data <- data.frame(replicate(10,sample(0:1,20,rep=TRUE)))
 #' names(eb_data) <- gsub(x = names(eb_data), pattern = "X", replacement = "Use_")  
-#' eb_data$informant<-sample(c('User_1', 'User_2', 'User_3'), 20, replace=TRUE)
-#' eb_data$sp_name<-sample(c('sp_1', 'sp_2', 'sp_3', 'sp_4'), 20, replace=TRUE)
-#' Radial_plot(data = eb_data, analysis = FCs)
+#' eb_data$informant <- sample(c('User_1', 'User_2', 'User_3'), 20, replace=TRUE)
+#' eb_data$sp_name <- sample(c('sp_1', 'sp_2', 'sp_3', 'sp_4'), 20, replace=TRUE)
+#'  
+#' Radial_plot(data = eb_data, analysis = URs)
 #' 
 #' @export Radial_plot
+#' 
 Radial_plot <- function(data, analysis) {
+  
+  #Add error stops ####
+  #Check that packages are loaded
+    {
   if (!requireNamespace("dplyr", quietly = TRUE)) {
     stop("Package \"dplyr\" needed for this function to work. Please install it.",
          call. = FALSE)
@@ -33,24 +48,24 @@ Radial_plot <- function(data, analysis) {
   if (!requireNamespace("magrittr", quietly = TRUE)) {
     stop("Package \"magrittr\" needed for this function to work. Please install it.",
          call. = FALSE)
-  }
+    }
+      }# end package check
+    
+    ## Check that use categories are greater than zero
+    if (!any(sum(dplyr::select(data, -informant, -sp_name)>0))){
+      warning("The sum of all UR is not greater than zero. Perhaps not all uses have values or are not numeric.")
+      data<-data[stats::complete.cases(data), ]
+    }
+    
+    ## Use 'complete.cases' from stats to get to the collection of obs without NA
+    if (any(is.na(data))) {
+      warning("Some of your observations included \"NA\" and were removed. Consider using \"0\" instead.")
+      data<-data[stats::complete.cases(data), ]
+    }#end error stops
   
+  # Set the variables to NULL first, appeasing R CMD check
   value <-  meltURdata <- URdata <- URs <- sp_name <- informant <- URps <- NULL # Setting the variables to NULL first, appeasing R CMD check
   
-  #add error stops with validate_that
-  assertthat::validate_that("informant" %in% colnames(data), msg = "The required column called \"informant\" is missing from your data. Add it.")
-  assertthat::validate_that("sp_name" %in% colnames(data), msg = "The required column called \"sp_name\" is missing from your data. Add it.")
-  
-  assertthat::validate_that(is.factor(data$informant), msg = "The \"informant\" is not a factor variable. Transform it.")
-  assertthat::validate_that(is.factor(data$sp_name), msg = "The \"sp_name\" is not a factor variable. Transform it.")
-  
-  assertthat::validate_that(all(sum(dplyr::select(data, -informant, -sp_name)>0)) , msg = "The sum of all UR is not greater than zero. Perhaps not all uses have values or are not numeric.")
-  
-  ## Use 'complete.cases' from stats to get to the collection of obs without NA
-  data_complete<-data[stats::complete.cases(data), ]
-  #message about complete cases
-  assertthat::see_if(length(data_complete) == length(data), msg = "Some of your observations included \"NA\" and were removed. Consider using \"0\" instead.")
- 
   Radial_plot_data <- analysis(data) #create subset-able data
   
   names(Radial_plot_data)[length(names(Radial_plot_data))]<-"value" 
